
.. _links:


Links
=====

This page lists links to various resources.


Aesara requirements
-------------------

- git_: A distributed revision control system (RCS).
- pytest_: A system for unit testing.
- numpy_: A library for efficient numerical computing.
- python_: The programming language in which Aesara is written.
- scipy_: A library for scientific computing.


Libraries we might want to look at or use
-----------------------------------------

This is a sort of memo for developers and would-be developers.

- autodiff_: Tools for automatic differentiation.
- boost.python_: An interoperability layer between Python and C++
- cython_: A language to write C extensions to Python.
- liboil_: A library for CPU-specific optimization.
- llvm_: A low-level virtual machine we might want to use for compilation.
- networkx_: A package to create and manipulate graph structures.
- pycppad_: Python bindings to an AD package in C++.
- pypy_: Optimizing compiler for Python in Python.
- shedskin_: An experimental (restricted-)Python-to-C++ compiler.
- swig_: An interoperability layer between Python and C/C++
- unpython_: Python to C compiler.



.. _git: http://git-scm.com/
.. _pytest: http://docs.pytest.org/en/latest/
.. _numpy: http://numpy.scipy.org/
.. _python: http://www.python.org
.. _scipy: http://scipy.org/

.. _autodiff: http://www.autodiff.org
.. _boost.python: http://www.boost.org/doc/libs/1_38_0/libs/python/doc/index.html
.. _cython: http://www.cython.org/
.. _liboil: http://liboil.freedesktop.org/wiki/
.. _llvm: http://llvm.org/
.. _networkx: http://networkx.lanl.gov/
.. _pypy: http://codespeak.net/pypy/dist/pypy/doc/
.. _swig: http://www.swig.org/
.. _unpython: http://code.google.com/p/unpython/
.. _pycppad: http://www.seanet.com/~bradbell/pycppad/index.xml
.. _shedskin: http://shed-skin.blogspot.com/
